from dz_phone_numbers import DzPhoneNumber
import pytest

def test_phone_carrier():
    with pytest.raises(ValueError):
        phone_number1 = DzPhoneNumber('055012llsd')
        phone_number2 = DzPhoneNumber('06501')
        phone_number3 = DzPhoneNumber('0750123')
        phone_number1.is_ooredoo()
        phone_number2.is_mobilis()
        phone_number3.is_djezzy()


class DzPhoneNumber:

    carriers = { 
        'ooredoo': '05',
        'mobilis': '06',
        'djezzy': '07'
    }

    def __init__(self, phone_number: str):
        self.phone_number = phone_number
        self.is_valid()

    def is_valid(self) -> bool: 
        if len(self.phone_number) != 10 or not self.phone_number.isdigit():
            raise ValueError("Invalid phone number")
        

    def get_phone_carrier(self): 
        for name, initial in self.carriers.items():
            if self.phone_number[:2] == initial:
                return name

        ValueError("Invalid phone carrier")

    def is_ooredoo(self): 
        return self.get_phone_carrier() == 'ooredoo'

    def is_mobilis(self): 
        return self.get_phone_carrier() == 'mobilis'

    def is_djezzy(self): 
        return self.get_phone_carrier() == 'djezzy'
    


from setuptools import find_packages, setup

PKG_NAME = "dz_phonenumbers"

dev_dependencies = ["pytest"]

setup(
    name=PKG_NAME,
    version="1.0.0",
    license="MIT",
    author="Walid Ziouche",
    author_email="hi@walid.dev",
    description="Algerian phone numbers as value object, python implementation",
    long_description="long_description",
    long_description_content_type="text/markdown",
    keywords="dz phone number tel telephone mobile regex",
    extras_require={"dev": dev_dependencies},
    packages=find_packages(),
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Intended Audience :: Developers",
        "Intended Audience :: Telecommunications Industry",
        "Topic :: Utilities",
        "Typing :: Typed",
        # Specify the Python versions you support here. In particular, ensure
        # that you indicate you support Python 3. These classifiers are *not*
        # checked by 'pip install'. See instead 'python_requires' below.
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3 :: Only",
    ],
    python_requires=">=3.6, <4",
    project_urls={
        "Bug Reports": "https://github.com/01walid/py-dz-phone-number/issues",
        "Source": "https://github.com/01walid/py-dz-phone-number",
    },
)